@@ -167,6 +167,14 @@ abstract class AbstractChannel
         return $this->method_queue;
     }
 
+    /**
+     * @return bool
+     */
+    public function hasPendingMethods()
+    {
+        return !empty($this->method_queue);
+    }
+
     /**
      * @param string $method_sig
      * @param string $args
