@@ -15,8 +15,10 @@ class AMQPSocketConnection extends AbstractConnection
      * @param string $login_method
      * @param null $login_response
      * @param string $locale
-     * @param float $timeout
+     * @param float $read_timeout
      * @param bool $keepalive
+     * @param int $write_timeout
+     * @param int $heartbeat
      */
     public function __construct(
         $host,
@@ -28,10 +30,12 @@ class AMQPSocketConnection extends AbstractConnection
         $login_method = 'AMQPLAIN',
         $login_response = null,
         $locale = 'en_US',
-        $timeout = 3,
-        $keepalive = false
+        $read_timeout = 3,
+        $keepalive = false,
+        $write_timeout = 3,
+        $heartbeat = 0
     ) {
-        $io = new SocketIO($host, $port, $timeout, $keepalive);
+        $io = new SocketIO($host, $port, $read_timeout, $keepalive, $write_timeout, $heartbeat);
 
         parent::__construct(
             $user,
@@ -41,7 +45,8 @@ class AMQPSocketConnection extends AbstractConnection
             $login_method,
             $login_response,
             $locale,
-            $io
+            $io,
+            $heartbeat
         );
     }
 }
