@@ -9,6 +9,8 @@ use PhpAmqpLib\Wire\AMQPWriter;
 
 class StreamIO extends AbstractIO
 {
+    const READ_BUFFER_WAIT_INTERVAL = 100000;
+
     /** @var string */
     protected $protocol;
 
@@ -48,9 +50,6 @@ class StreamIO extends AbstractIO
     /** @var resource */
     private $sock;
 
-    /** @var bool */
-    private $canSelectNull;
-
     /** @var bool */
     private $canDispatchPcntlSignal;
 
@@ -85,17 +84,21 @@ class StreamIO extends AbstractIO
         $this->keepalive = $keepalive;
         $this->heartbeat = $heartbeat;
         $this->initial_heartbeat = $heartbeat;
-        $this->canSelectNull = true;
         $this->canDispatchPcntlSignal = $this->isPcntlSignalEnabled();
 
         if (is_null($this->context)) {
-            $this->context = stream_context_create();
+            // tcp_nodelay was added in 7.1.0
+            if (PHP_VERSION_ID >= 70100) {
+                $this->context = stream_context_create(array(
+                    "socket" => array(
+                        "tcp_nodelay" => true
+                    )
+                ));
+            } else {
+                $this->context = stream_context_create();
+            }
         } else {
             $this->protocol = 'ssl';
-            // php bugs 41631 & 65137 prevent select null from working on ssl streams
-            if (PHP_VERSION_ID < 50436) {
-                $this->canSelectNull = false;
-            }
         }
     }
 
@@ -226,14 +229,8 @@ class StreamIO extends AbstractIO
 
             if ($buffer === '') {
                 if ($this->canDispatchPcntlSignal) {
-                    // prevent cpu from being consumed while waiting
-                    if ($this->canSelectNull) {
-                        $this->select(null, null);
-                        pcntl_signal_dispatch();
-                    } else {
-                        usleep(100000);
-                        pcntl_signal_dispatch();
-                    }
+                    $this->select(0, self::READ_BUFFER_WAIT_INTERVAL);
+                    pcntl_signal_dispatch();
                 }
                 continue;
             }
@@ -341,7 +338,7 @@ class StreamIO extends AbstractIO
     /**
      * Heartbeat logic: check connection health here
      */
-    protected function check_heartbeat()
+    public function check_heartbeat()
     {
         // ignore unless heartbeat interval is set
         if ($this->heartbeat !== 0 && $this->last_read && $this->last_write) {
